@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ContactTemplateListWidget : public PimCommon::TemplateListWidget
     Q_OBJECT
 public:
     explicit ContactTemplateListWidget(const QString &configName, QWidget *parent = nullptr);
-    ~ContactTemplateListWidget();
+    ~ContactTemplateListWidget() override;
 
     QVector<PimCommon::defaultTemplate> defaultTemplates() override;
 };
