@@ -72,7 +72,7 @@ private:
     QString projectDirectory() const;
     void createZip(const QString &themeName, KZip *zip);
     EditorPage *createExtraPage(const QString &filename);
-    QList<EditorPage *> mExtraPage;
+    QVector<EditorPage *> mExtraPage;
     GrantleeThemeEditor::ThemeEditorTabWidget *mTabWidget = nullptr;
     EditorPage *mEditorPage = nullptr;
     GrantleeThemeEditor::DesktopFilePage *mDesktopPage = nullptr;
